@@ -137,6 +137,7 @@ int eXosip_execute(struct eXosip_t *excontext);
 #define EXOSIP_OPT_SET_DEFAULT_CONTACT_DISPLAYNAME (EXOSIP_OPT_BASE_OPTION + 31) /**< char *: define a display name to be added in Contact headers  (example: "john Doe") */
 #define EXOSIP_OPT_SET_SESSIONTIMERS_FORCE \
   (EXOSIP_OPT_BASE_OPTION + 32) /**< int *: 0 (default): activate "session timers" if supported on both side, 1: if remote side (UAS) do not indicate support for "session timers", activate feature on UAC (local) side */
+#define EXOSIP_OPT_FORCE_CONNECTIONREUSE (EXOSIP_OPT_BASE_OPTION + 33)           /**< int *: 0 to disable, 1 to force reusing established connection for ACK and dialog message */
 
 #define EXOSIP_OPT_SET_TLS_VERIFY_CERTIFICATE (EXOSIP_OPT_BASE_OPTION + 500)      /**< int *: enable verification of certificate for TLS connection */
 #define EXOSIP_OPT_SET_TLS_CERTIFICATES_INFO (EXOSIP_OPT_BASE_OPTION + 501)       /**< eXosip_tls_ctx_t *: client and/or server certificate/ca-root/key info */
@@ -248,6 +249,9 @@ typedef struct eXosip_tls_ctx_s {
   char random_file[1024];          /**< absolute path to a file with random(!) data */
   char dh_param[1024];             /**< absolute path to a file necessary for diffie hellman key exchange */
   char root_ca_cert[1024];         /**< absolute path to the file with known rootCAs */
+  char cipher_list[2048];          /**< openssl cipher list (default: HIGH:!COMPLEMENTOFDEFAULT:!kRSA:!PSK:!SRP) */
+  unsigned long tls_flags;         /**< openssl additionnal flag (example: SSL_OP_NO_TLSv1, SSL_OP_NO_TLSv1_1) */
+  unsigned long dtls_flags;        /**< openssl additionnal flag (example: SSL_OP_NO_DTLSv1) */
   eXosip_tls_credentials_t client; /**< credential of the client */
   eXosip_tls_credentials_t server; /**< credential of the server */
 } eXosip_tls_ctx_t;
