@@ -1507,7 +1507,7 @@ static void _eXosip_process_response_out_of_transaction(struct eXosip_t *exconte
   return;
 }
 
-static int _eXosip_handle_rfc5626_ob(osip_message_t *message, char *remote_host, int remote_port) {
+static int _eXosip_handle_rfc5626_ob(struct eXosip_t *excontext, osip_message_t *message, char *remote_host, int remote_port) {
   osip_contact_t *co;
   osip_uri_param_t *u_param = NULL;
   char _remote_port[10];
@@ -1536,8 +1536,12 @@ static int _eXosip_handle_rfc5626_ob(osip_message_t *message, char *remote_host,
 
   osip_uri_uparam_get_byname(co->url, "ob", &u_param);
 
-  if (u_param == NULL || u_param->gname == NULL)
-    return OSIP_SUCCESS;
+  if (u_param == NULL || u_param->gname == NULL) {
+    if (excontext->opt_force_connectionreuse > 0)
+      osip_uri_uparam_add(co->url, osip_strdup("ob"), NULL);
+    else
+      return OSIP_SUCCESS;
+  }
 
   /* add internal x-ob parameters with connection info */
   osip_uri_uparam_add(co->url, osip_strdup("x-obr"), osip_strdup(remote_host));
@@ -1735,7 +1739,7 @@ int _eXosip_handle_incoming_message(struct eXosip_t *excontext, char *buf, size_
   }
 
   osip_message_fix_last_via_header(se->sip, host, port);
-  _eXosip_handle_rfc5626_ob(se->sip, host, port);
+  _eXosip_handle_rfc5626_ob(excontext, se->sip, host, port);
 
   if (MSG_IS_RESPONSE(se->sip)) {
     _eXosip_handle_received_rport(se->sip, received_host, rport_port);
@@ -1872,6 +1876,19 @@ int _eXosip_read_message(struct eXosip_t *excontext, int max_message_nb, int sec
       _eXosip_dnsutils_delsock_epoll(excontext, cares_fd_table);
       eXosip_unlock(excontext);
 
+      for (i = 0; i < EXOSIP_MAX_SOCKETS; i++) {
+        if (osip_fd_table[i] > 0) {
+          for (n = 0; n < nfds; ++n) {
+            if (excontext->ep_array[n].events & EPOLLIN && excontext->ep_array[n].data.fd == osip_fd_table[i]) {
+              excontext->eXtl_transport.tl_check_connection(excontext, osip_fd_table[i]);
+            }
+            if (excontext->ep_array[n].events & EPOLLOUT && excontext->ep_array[n].data.fd == osip_fd_table[i]) {
+              excontext->eXtl_transport.tl_check_connection(excontext, osip_fd_table[i]);
+            }
+          }
+        }
+      }
+
       /* only check for connection/keepalive when there is no activity */
       osip_gettimeofday(&excontext->cc_timer, NULL);
       add_gettimeofday(&excontext->cc_timer, 5000);
@@ -1957,6 +1974,8 @@ int _eXosip_read_message(struct eXosip_t *excontext, int max_message_nb, int sec
 
         for (i = 0; i < EXOSIP_MAX_SOCKETS; i++) {
           if (osip_fd_table[i] > 0) {
+            if (FD_ISSET(osip_fd_table[i], &osip_fdset))
+              excontext->eXtl_transport.tl_check_connection(excontext, osip_fd_table[i]);
             if (FD_ISSET(osip_fd_table[i], &osip_wrset))
               excontext->eXtl_transport.tl_check_connection(excontext, osip_fd_table[i]);
             if (FD_ISSET(osip_fd_table[i], &osip_exceptset))
